@@ -5,17 +5,16 @@
    Created: 4 Jan 2004
    Updated: 2 April 2008    some functions moved to utilities.c
    Updated: 25 August 2016  mvnEstat converted to c++ in mvnorm.cpp
+   Updated: 16 February 2021  poisMstat ported to Rcpp in poissonM.cpp
 
    ksampleEtest() performs the multivariate E-test for equal distributions,
                   complete version, from data matrix
    E2sample()     computes the 2-sample E-statistic without creating distance
-   poisMstat()    computes the mean distance test of Poissonity
 */
 
 #include <R.h>
 #include <Rmath.h>
 
-void   poisMstat(int *x, int *nx, double *stat);
 void   ksampleEtest(double *x, int *byrow, int *nsamples, int *sizes, int *dim,
             int *R, double *e0, double *e, double *pval);
 void   E2sample(double *x, int *sizes, int *dim, double *stat);
@@ -43,53 +42,6 @@ extern void   index_distance(double *x, double **Dx, int n, int d, double index)
 extern void   sumdist(double *x, int *byrow, int *nrow, int *ncol, double *lowersum);
 
 
-void poisMstat(int *x, int *nx, double *stat)
-{
-    /* computes the Poisson mean distance statistic */
-    int i, j, k, n=(*nx);
-    double eps=1.0e-10;
-    double cvm, d, lambda, m, q;
-    double Mcdf1, Mcdf0, Mpdf1, cdf1, cdf0;
-
-    lambda = 0;
-    for (i=0; i<n; i++)
-        lambda += x[i];
-    lambda /= ((double) n);
-    q = qpois(1.0-eps, lambda, TRUE, FALSE) + 1;
-
-    m = 0.0;
-    for (j=0; j<n; j++) m += abs(x[j] - 1);
-    m /= ((double) n);                   /* est of m_1 = E|1 - X| */
-    Mcdf0 = (m + 1.0 - lambda) / 2.0;    /* M-est of F(0) */
-
-    cdf0 = exp(-lambda);                 /* MLE of F(0) */
-    d = Mcdf0 - cdf0;
-    cvm = d * d * cdf0;   /* von Mises type of distance */
-
-    for (i=1; i<q; i++) {
-        m = 0;
-        k = i + 1;
-        for (j=0; j<n; j++) m += abs(x[j]-k);
-        m /= ((double) n);  /* est of m_{i+1} = E|i+1 - X| */
-
-        /* compute M-estimate of f(i) and F(i) */
-        Mpdf1 = (m-(k-lambda)*(2.0*Mcdf0-1.0))/((double) 2.0*k);
-        if (Mpdf1 < 0.0) Mpdf1 = 0.0;
-        Mcdf1 = Mcdf0 + Mpdf1;
-        if (Mcdf1 > 1) Mcdf1 = 1.0;
-
-        cdf1 = ppois(i, lambda, TRUE, FALSE); /* MLE of F(i) */
-        d = Mcdf1 - cdf1;
-        cvm += d * d * (cdf1 - cdf0);
-
-        cdf0 = cdf1;
-        Mcdf0 = Mcdf1;
-    }
-    cvm *= n;
-    *stat = cvm;
-}
-
-
 void E2sample(double *x, int *sizes, int *dim, double *stat) {
     /*
       compute test statistic *stat for testing H:F=G
